## 0.10.4 (2023-04-29)

### Fix

- **sparser.py**: getiteritems was deprecated for iter in python 3.9
- under some conditions it wasn't finding the parsing definition file

### Refactor

- small refactors from black, isort, and ruff

## 0.10.3 (2023-01-16)

## 0.10.2 (2023-01-08)

## 0.10.1 (2022-09-29)

### Refactor

- updated pyproject.toml

## 0.10.0 (2022-07-16)

### Feat

- uses tstoolbox read to support csv, wdm, hdf5, and xlsx files
- use tstoolbox.read

## 0.9.6 (2022-07-13)

### Fix

- needed an __init__.py to identify the package

## 0.9.5 (2022-07-04)

### Refactor

- complete refactor to style i use in the toolboxes plus several fixes
- removed __future__

## 0.9.4 (2022-04-16)

### Fix

- removed filelike library as a dependency
- **setup.py**: fixed location of scripts and packages in setup.py

## 0.9.3 (2022-04-16)

### Fix

- **2to3**: edited to support python 3, no longer supporting python 2
